pub enum RegionalRailStop {
Show 157 variants AirportTerminalEF, AirportTerminalCD, AirportTerminalB, AirportTerminalA, Eastwick, Stenton, Wyndmoor, Wister, Gravers, Germantown, Sedgwick, ChestnutHillEast, WashingtonLane, MountAiry, NorthPhiladelphia, Upsal, StMartins, ChestnutHillWest, CheltenAvenue, Carpenter, RichardAllenLane, Tulpehocken, Highland, QueenLane, Cynwyd, Bala, WynnefieldAvenue, FoxChase, Ryers, Cheltenham, Lawndale, Olney, Doylestown, DelawareValleyCollege, NewBritain, Chalfont, LinkBelt, Colmar, Fortuna, NinthStreetLansdale, Lansdale, Pennbrook, NorthWales, GwyneddValley, Penllyn, Ambler, FortWashington, Oreland, NorthHills, NorthBroad, Wawa, Elwyn, Media, MoylanRoseValley, Wallingford, Swarthmore, Morton, Secane, Primos, CliftonAldan, Gladstone, Lansdowne, FernwoodYeadon, Angora, FortyNinthStreet, NorristownElmStreet, MainStreet, NorristownTC, Conshohocken, SpringMill, Miquon, IvyRidge, Manayunk, Wissahickon, EastFalls, Allegheny, Thorndale, Downingtown, Whitford, Exton, Malvern, Paoli, Wayne, StDavids, Berwyn, Devon, Villanova, Rosemont, BrynMawr, Strafford, Daylesford, Radnor, Haverford, Ardmore, Wynnewood, Narberth, Overbrook, Merion, Trenton, Levittown, Bristol, Croydon, Eddington, CornwellsHeights, Torresdale, HolmesburgJct, Tacony, Bridesburg, NorthPhiladelphiaAmtrak, Warminster, Hatboro, WillowGrove, Crestmont, Roslyn, Ardsley, Newark, ChurchmansCrossing, Wilmington, Claymont, MarcusHook, HighlandAvenue, Chester, Eddystone, CrumLynne, RidleyPark, ProspectParkMoore, Norwood, Glenolden, Folcroft, SharonHill, CurtisPark, Darby, WestTrenton, Yardley, Woodbourne, Langhorne, Neshaminy, Trevose, Somerton, ForestHills, Philmont, Bethayres, Meadowbrook, Rydal, Noble, WayneJunction, Glenside, JenkintownWyncote, FernRockTC, ElkinsPark, MelrosePark, Gray30thStreet, SuburbanStation, JeffersonStation, TempleUniversity, PennMedicineStation, Unknown(String),
}

Variants



AirportTerminalEF



AirportTerminalCD



AirportTerminalB



AirportTerminalA



Eastwick



Stenton



Wyndmoor



Wister



Gravers



Germantown



Sedgwick



ChestnutHillEast



WashingtonLane



MountAiry



NorthPhiladelphia



Upsal



StMartins



ChestnutHillWest



CheltenAvenue



Carpenter



RichardAllenLane



Tulpehocken



Highland



QueenLane



Cynwyd



Bala



WynnefieldAvenue



FoxChase



Ryers



Cheltenham



Lawndale



Olney



Doylestown



DelawareValleyCollege



NewBritain



Chalfont



LinkBelt



Colmar



Fortuna



NinthStreetLansdale



Lansdale



Pennbrook



NorthWales



GwyneddValley



Penllyn



Ambler



FortWashington



Oreland



NorthHills



NorthBroad



Wawa



Elwyn



Media



MoylanRoseValley



Wallingford



Swarthmore



Morton



Secane



Primos



CliftonAldan



Gladstone



Lansdowne



FernwoodYeadon



Angora



FortyNinthStreet



NorristownElmStreet



MainStreet



NorristownTC



Conshohocken



SpringMill



Miquon



IvyRidge



Manayunk



Wissahickon



EastFalls



Allegheny



Thorndale



Downingtown



Whitford



Exton



Malvern



Paoli



Wayne



StDavids



Berwyn



Devon



Villanova



Rosemont



BrynMawr



Strafford



Daylesford



Radnor



Haverford



Ardmore



Wynnewood



Narberth



Overbrook



Merion



Trenton



Levittown



Bristol



Croydon



Eddington



CornwellsHeights



Torresdale



HolmesburgJct



Tacony



Bridesburg



NorthPhiladelphiaAmtrak



Warminster



Hatboro



WillowGrove



Crestmont



Roslyn



Ardsley



Newark



ChurchmansCrossing



Wilmington



Claymont



MarcusHook



HighlandAvenue



Chester



Eddystone



CrumLynne



RidleyPark



ProspectParkMoore



Norwood



Glenolden



Folcroft



SharonHill



CurtisPark



Darby



WestTrenton



Yardley



Woodbourne



Langhorne



Neshaminy



Trevose



Somerton



ForestHills



Philmont



Bethayres



Meadowbrook



Rydal



Noble



WayneJunction



Glenside



JenkintownWyncote



FernRockTC



ElkinsPark



MelrosePark



Gray30thStreet



SuburbanStation



JeffersonStation



TempleUniversity



PennMedicineStation



Unknown(String)

Implementations